# AbuseIpDb
## Wrapper around the AbuseIPDb service API

This was a project born of having to do this in an automated fashion for our internal systems, and not finding a decent
Python 2.7 package worth installing.

Source code can be found here:

[https://github.com/vsecades/AbuseIpDb][src].

----

